Crate valor_core

Valor

A lightweight HTTP plugin system that runs in the server and the browser.

  • Use valor_bin to run your Rust and JS(soon!) plugins in the server.
  • Use valor_web as a script imported from the main document or a worker in your web application to have a local API powered by a service worker.

Re-exports

Structs

  • Context allows plugins to pass state to the message handler and eventually to easily communicate with other plugins.

Enums

  • Type of valid outputs that a handler can return
  • Type of message supported by a handler

Traits

  • The Vlugin trait defines plugins that can handle any supported message format. It also allows the plugin to initialize an internal state with the help of the Context type.

Functions

  • Shorthand for handlers created from a closure

Type Aliases

Attribute Macros